@@ -24,8 +24,6 @@
 #include <powerdevilaction.h>
 #include <powerdevilbackendinterface.h>
 
-// class BrightnessOSDWidget;
-
 namespace PowerDevil {
 namespace BundledActions {
 
@@ -51,8 +49,7 @@ public:
     virtual bool loadAction(const KConfigGroup& config);
 
 public Q_SLOTS:
-    void showBrightnessOSD(int brightness);
-    void onBrightnessChangedFromBackend(int brightnessValue, int brightnessValueMax, PowerDevil::BackendInterface::BrightnessControlType type);
+    void onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &brightnessInfo, BackendInterface::BrightnessControlType type);
 
     // DBus export
     void increaseKeyboardBrightness();
@@ -61,18 +58,24 @@ public Q_SLOTS:
 
     int keyboardBrightness() const;
     void setKeyboardBrightness(int percent);
+    void setKeyboardBrightnessSilent(int percent);
 
     int keyboardBrightnessValue() const;
     int keyboardBrightnessValueMax() const;
     void setKeyboardBrightnessValue(int value);
+    void setKeyboardBrightnessValueSilent(int value);
+
+    int keyboardBrightnessStep() const;
+    int keyboardBrightnessStepMax() const;
+    void setKeyboardBrightnessStep(int step);
 
 Q_SIGNALS:
     void keyboardBrightnessChanged(int percent);
     void keyboardBrightnessValueChanged(int value);
+    void keyboardBrightnessStepChanged(int step);
 
 private:
     int m_defaultValue;
-//     QWeakPointer< BrightnessOSDWidget > m_brightnessOSD;
     QString m_lastProfile;
     QString m_currentProfile;
 };
