@@ -26,7 +26,7 @@
 #include <QtCore/QWeakPointer>
 #include <QtCore/QStringList>
 
-#include <KComponentData>
+#include <KSharedConfig>
 
 namespace KActivities
 {
@@ -35,8 +35,10 @@ namespace KActivities
 typedef QMap< QString, QString > StringStringMap;
 
 class KDirWatch;
+class QDBusServiceWatcher;
 class QTimer;
 class KNotification;
+
 namespace Solid {
 class Battery;
 }
@@ -54,7 +56,7 @@ class Q_DECL_EXPORT Core : public QObject
     Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement")
 
 public:
-    explicit Core(QObject* parent/*, const KComponentData &componentData*/);
+    explicit Core(QObject* parent);
     virtual ~Core();
 
     void reloadProfile(int state);
@@ -81,7 +83,8 @@ public Q_SLOTS:
 
     qulonglong batteryRemainingTime() const;
 
-    bool isLidClosed();
+    bool isLidClosed() const;
+    bool isLidPresent() const;
     bool isActionSupported(const QString &actionName);
 
 Q_SIGNALS:
@@ -106,7 +109,8 @@ private:
     QStringList m_loadedBatteriesUdi;
 
     QWeakPointer< KNotification > notification;
-//     KComponentData m_applicationData;
+    QDBusServiceWatcher *m_notificationsWatcher;
+
     KSharedConfigPtr m_profilesConfig;
 
     QString m_currentProfile;
@@ -139,6 +143,8 @@ private Q_SLOTS:
     void onDeviceAdded(const QString &udi);
     void onDeviceRemoved(const QString &udi);
     void onCriticalBatteryTimerExpired();
+    void onNotificationTimeout();
+    void onServiceRegistered(const QString &service);
 };
 
 }
